Learn R Programming

fanovaGraph (version 1.5)

i2Index: Estimation of pure second order indices

Description

Estimation of the unscaled pure second order Sobol indices.

Usage

i2Index(f.mat, d, q = NULL, q.arg = NULL, n.i2, ...)

Arguments

f.mat

vectorized function of which indices shall be estimated

d

integer, number of input factors (vertices)

q

a vector of character strings of quantile functions corresponding to the factors distributions, it can be a single character string meaning same distribution for all, if not specified "qunif" is taken

q.arg

a list of lists of quantile functions parameters of the distributions in q, it can be a single list meaning same parameters for all, if not specified the default values of the respective distributions are taken

n.i2

number of Monte Carlo evaluations

…

additional arguments to be passed to the function f.mat

Value

A vector containing the unscaled pure second order indices

References

Sobol', I. M. (1993) Sensitivity estimates for nonlinear mathematical models, Mathematical Modeling and Computational Experiment, 1, 407-414.

See Also

estimateGraph totalIndex

Examples

Run this code
# NOT RUN {
i2Index(f.mat=ishigami.fun, d=3, q.arg=list(min=-pi,max=pi), n.i2=10000)
# }

Run the code above in your browser using DataLab